@@ -1,13 +1,14 @@
 #' @title Evaluate your model's performance
-#' @description Evaluate your model's predictions
+#' @description
+#'  \Sexpr[results=rd, stage=render]{lifecycle::badge("maturing")}
+#'
+#'  Evaluate your model's predictions
 #'  on a set of evaluation metrics.
 #'
 #'  Create ID-aggregated evaluations by multiple methods.
 #'
-#'  Currently supports linear regression, binary classification
-#'  and multiclass classification (see \code{type}).
-#'
-#'  \strong{evaluate() is under development! Large changes may occur.}
+#'  Currently supports regression and classification
+#'  (binary and multiclass). See \code{type}.
 #' @param data Data frame with predictions, targets and (optionally) an ID column.
 #'  Can be grouped with \code{\link[dplyr]{group_by}}.
 #'
@@ -118,7 +119,7 @@
 #'   N.B. Currently, disabled metrics are still computed.
 #' @param type Type of evaluation to perform:
 #'
-#'  \code{"gaussian"} for linear regression.
+#'  \code{"gaussian"} for regression (like linear regression).
 #'
 #'  \code{"binomial"} for binary classification.
 #'
@@ -137,38 +138,43 @@
 #'
 #'  AIC : \code{\link[stats:AIC]{stats::AIC}}
 #'
-#'  AICc : \code{\link[AICcmodavg:AICc]{AICcmodavg::AICc}}
+#'  AICc : \code{\link[MuMIn:AICc]{MuMIn::AICc}}
 #'
 #'  BIC : \code{\link[stats:BIC]{stats::BIC}}
 #'
 #'  \strong{Binomial} and \strong{Multinomial}:
 #'
-#'  Confusion matrix and related metrics: \code{\link[caret:confusionMatrix]{caret::confusionMatrix}}
+#'  Confusion matrix and related metrics:
+#'  \code{\link[caret:confusionMatrix]{caret::confusionMatrix}}
 #'
 #'  ROC and related metrics: \code{\link[pROC:roc]{pROC::roc}}
 #'
 #'  MCC: \code{\link[mltools:mcc]{mltools::mcc}}
 #'
+#' @return
 #'  ----------------------------------------------------------------
 #'
 #'  \subsection{Gaussian Results}{
 #'
 #'  ----------------------------------------------------------------
 #'
-#'  Single tibble containing the following metrics by default:
+#'  Tibble containing the following metrics by default:
 #'
 #'  Average \strong{RMSE}, \strong{MAE}, \strong{r2m},
 #'  \strong{r2c}, \strong{AIC}, \strong{AICc}, and \strong{BIC}.
 #'
 #'  N.B. Some of the metrics will only be returned if model
-#'  objects were passed, and \code{NA} if they could not be
+#'  objects were passed, and will be \code{NA} if they could not be
 #'  extracted from the passed model objects.
 #'
 #'  Also includes:
 #'
-#'  A nested tibble with the \strong{Predictions} and targets
+#'  A nested tibble with the \strong{Predictions} and targets.
 #'
-#'  A nested tibble with the model \strong{Coefficients}.
+#'  A nested tibble with the model \strong{Coefficients}. The coefficients
+#'  are extracted from the model object with \code{\link[broom:tidy]{broom::tidy()}} or
+#'  \code{\link[stats:coef]{coef()}} (with some restrictions on the output).
+#'  If these attempts fail, a default coefficients tibble filled with \code{NA}s is returned.
 #'  }
 #'
 #'  ----------------------------------------------------------------
@@ -177,7 +183,7 @@
 #'
 #'  ----------------------------------------------------------------
 #'
-#'  A single tibble with the following evaluation metrics, based on a
+#'  Tibble with the following evaluation metrics, based on a
 #'  confusion matrix and a ROC curve fitted to the predictions:
 #'
 #'  ROC:
@@ -213,38 +219,24 @@
 #'  depending on which level is the "\code{positive}" class. I.e. the level you wish to predict.
 #'  }
 #'
-#' ----------------------------------------------------------------
+#'  ----------------------------------------------------------------
 #'
 #'  \subsection{Multinomial Results}{
 #'
 #'  ----------------------------------------------------------------
 #'
-#'  A list with two tibbles:
+#'  For each class, a \emph{one-vs-all} binomial evaluation is performed. This creates
+#'  a \strong{Class Level Results} tibble containing the same metrics as the binomial results
+#'  described above, along with the \strong{Support} metric, which is simply a
+#'  count of the class in the target column. These metrics are used to calculate the macro metrics
+#'  in the output tibble. The nested class level results tibble is also included in the output tibble,
+#'  and would usually be reported along with the macro and overall metrics.
 #'
-#'  \strong{Class Level Results}
-#'
-#'  The \code{Class Level Results} tibble contains the results of the \emph{one-vs-all}
-#'  binomial evaluations. It contains the same metrics as the binomial results described above.
-#'
-#'  Also includes:
-#'
-#'  A nested tibble with the \strong{Predictions} and targets used for the one-vs-all evaluation.
-#'
-#'  A nested tibble with the sensativities and specificities from the \strong{ROC} curve.
-#'
-#'  A nested tibble with the \strong{Confusion Matrix} from the one-vs-all evaluation.
-#'  The \code{Pos_} columns tells you whether a row is a
-#'  True Positive (TP), True Negative (TN), False Positive (FP), or False Negative (FN),
-#'  depending on which level is the "positive" class. In our case, \code{1} is the current class
-#'  and \code{0} represents all the other classes together.
-#'
-#'  \strong{Results}
-#'
-#'  The \code{Results} tibble contains the overall/macro metrics. The metrics that share their name
-#'  with the metrics in the Class Level Results tibble are averages of those metrics
+#'  The output tibble contains the macro and overall metrics.
+#'  The metrics that share their name with the metrics in the nested
+#'  class level results tibble are averages of those metrics
 #'  (note: does not remove \code{NA}s before averaging).
-#'  In addition to these, it also includes the \strong{Overall Accuracy} metric
-#'  and the \strong{Support} metric, which is simply a count of the class in the target column.
+#'  In addition to these, it also includes the \strong{Overall Accuracy} metric.
 #'
 #'  Other available metrics (disabled by default, see \code{metrics}):
 #'  \strong{Accuracy}, \strong{Weighted Balanced Accuracy}, \strong{Weighted Accuracy},
@@ -263,6 +255,19 @@
 #'
 #'  A nested tibble with the multiclass \strong{Confusion Matrix}.
 #'  }
+#'
+#'  \strong{Class Level Results}
+#'
+#'  Besides the binomial evaluation metrics and the \code{Support} metric,
+#'  the nested class level results tibble also contains:
+#'
+#'  A nested tibble with the sensativities and specificities from the \strong{ROC} curve.
+#'
+#'  A nested tibble with the \strong{Confusion Matrix} from the one-vs-all evaluation.
+#'  The \code{Pos_} columns tells you whether a row is a
+#'  True Positive (TP), True Negative (TN), False Positive (FP), or False Negative (FN),
+#'  depending on which level is the "positive" class. In our case, \code{1} is the current class
+#'  and \code{0} represents all the other classes together.
 #' @author Ludvig Renbo Olsen, \email{r-pkgs@@ludvigolsen.dk}
 #' @export
 #' @examples
@@ -298,7 +303,7 @@
 #'
 #' # Multinomial
 #'
-#' # Create a dataset
+#' # Create a tibble with predicted probabilities
 #' data_mc <- multiclass_probability_tibble(
 #'     num_classes = 3, num_observations = 30,
 #'     apply_softmax = TRUE, FUN = runif,
@@ -400,17 +405,12 @@ evaluate <- function(data,
 ){
 
   # Test if type is allowed
-  stopifnot(type %in% c("gaussian", "gaussian_regression", "linear_regression",
-                        "binomial", "binomial_classification", "binary_classification",
-                        "multinomial", "multinomial_classification", "multiclass_classification")) #"multilabel"))
+  stopifnot(type %in% c("gaussian",
+                        "binomial",
+                        "multinomial"))
 
   # Convert families to the internally used
-  if (type %in% c("gaussian", "gaussian_regression", "linear_regression")){
-    family <- "gaussian"}
-  if (type %in% c("binomial", "binomial_classification", "binary_classification")){
-    family <- "binomial"}
-  if (type %in% c("multinomial", "multinomial_classification", "multiclass_classification")){
-    family <- "multinomial"}
+  family <- type
 
   # Check the passed arguments TODO Add more checks
   check_args_evaluate(data = data,
@@ -434,7 +434,8 @@ evaluate <- function(data,
     link = NULL,
     cutoff = cutoff,
     positive = positive,
-    model_verbose = FALSE
+    model_verbose = FALSE,
+    caller = "evaluate()"
   ) %>%
     basics_update_model_specifics()
 
@@ -652,10 +653,19 @@ run_evaluate_wrapper <- function(data,
       dplyr::slice(rep(1:dplyr::n(), each = num_classes)) %>%
       dplyr::bind_cols(class_level_results)
 
-    return(
-      list("Results" = results,
-         "Class Level Results" = class_level_results)
-    )
+    # Nest class level results
+    class_level_results <- class_level_results %>%
+      dplyr::group_by_at(colnames(grouping_keys)) %>%
+      dplyr::group_nest(keep = TRUE) %>%
+      dplyr::pull(.data$data)
+
+    # Add class level results before predictions
+    results <- results %>%
+      tibble::add_column(`Class Level Results` = class_level_results,
+                         .before = "Predictions")
+
+    return(results)
+
   } else {
 
     # Bind evaluations
@@ -696,8 +706,7 @@ internal_evaluate <- function(data,
                                 type == "multinomial" ~ FALSE
                               )) {
 
-  stopifnot(type %in% c("linear_regression", "gaussian", "binomial", "multinomial")) #, "multiclass", "multilabel"))
-  if (type == "linear_regression") type <- "gaussian"
+  stopifnot(type %in% c("gaussian", "binomial", "multinomial")) #, "multiclass", "multilabel"))
 
   # Fill metrics with default values for non-specified metrics
   # and get the names of the metrics
